import time

from iwla import IWLA
from iplugin import IPlugin
from display import *

class IWLADisplayReferers(IPlugin):
    def __init__(self, iwla):
        super(IWLADisplayReferers, self).__init__(iwla)
        self.API_VERSION = 1
        self.requires = ['IWLAPostAnalysisReferers']

    def hook(self):
        month_stats = self.iwla.getMonthStats()
        referers = month_stats.get('referers', {})
        robots_referers = month_stats.get('robots_referers', {})
        search_engine_referers = month_stats.get('search_engine_referers', {})
        key_phrases = month_stats.get('key_phrases', {})

        top_referers = [(k, referers[k]['pages']) for k in referers.keys()]
        top_referers = sorted(top_referers, key=lambda t: t[1], reverse=True)

        top_robots_referers = [(k, robots_referers[k]['pages']) for k in robots_referers.keys()]
        top_robots_referers = sorted(top_robots_referers, key=lambda t: t[1], reverse=True)

        top_search_engine_referers = [(k, search_engine_referers[k]['pages']) for k in search_engine_referers.keys()]
        top_search_engine_referers = sorted(top_search_engine_referers, key=lambda t: t[1], reverse=True)

        top_key_phrases = key_phrases.items()
        top_key_phrases = sorted(top_key_phrases, key=lambda t: t[1], reverse=True)

        cur_time = self.iwla.getCurTime()
        index = self.iwla.getDisplayIndex()

        # All referers in a file
        title = time.strftime('Connexion from - %B %Y', cur_time)

        filename = 'referers.html'
        path = self.iwla.getCurDisplayPath(filename)

        page = DisplayHTMLPage(title, path)
        table = DisplayHTMLBlockTable('Connexion from', ['Origin', 'Pages', 'Hits'])
        table.setColsCSSClass(['', 'iwla_page', 'iwla_hit'])

        table.appendRow(['<b>Search Engine</b>', '', ''])
        for r,_ in top_search_engine_referers:
            row = [r, search_engine_referers[r]['pages'], search_engine_referers[r]['hits']]
            table.appendRow(row)

        table.appendRow(['<b>External URL</b>', '', ''])
        for r,_ in top_referers:
            row = [r, referers[r]['pages'], referers[r]['hits']]
            table.appendRow(row)

        table.appendRow(['<b>External URL (robot)</b>', '', ''])
        for r,_ in top_robots_referers:
            row = [r, robots_referers[r]['pages'], robots_referers[r]['hits']]
            table.appendRow(row)

        page.appendBlock(table)

        display = self.iwla.getDisplay()
        display.addPage(page)

        link = '<a href=\'%s\'>All referers</a>' % (filename)

        # Top referers in index
        title = '%s - %s' % ('Connexion from', link)

        table = DisplayHTMLBlockTable(title, ['Origin', 'Pages', 'Hits'])
        table.setColsCSSClass(['', 'iwla_page', 'iwla_hit'])

        table.appendRow(['<b>Search Engine</b>', '', ''])
        for r,_ in top_search_engine_referers[:10]:
            row = [r, search_engine_referers[r]['pages'], search_engine_referers[r]['hits']]
            table.appendRow(row)

        table.appendRow(['<b>External URL</b>', '', ''])
        for r,_ in top_referers[:10]:
            row = [r, referers[r]['pages'], referers[r]['hits']]
            table.appendRow(row)

        table.appendRow(['<b>External URL (robot)</b>', '', ''])
        for r,_ in top_robots_referers[:10]:
            row = [r, robots_referers[r]['pages'], robots_referers[r]['hits']]
            table.appendRow(row)

        index.appendBlock(table)

        # All key phrases in a file
        title = time.strftime('Key Phrases - %B %Y', cur_time)

        filename = 'key_phrases.html'
        path = self.iwla.getCurDisplayPath(filename)

        page = DisplayHTMLPage(title, path)
        table = DisplayHTMLBlockTable('Top key phrases', ['Key phrase', 'Search'])
        table.setColsCSSClass(['', 'iwla_search'])
        for phrase in top_key_phrases:
            table.appendRow([phrase[0], phrase[1]])
        page.appendBlock(table)
                        
        display.addPage(page)

        link = '<a href=\'%s\'>All key phrases</a>' % (filename)

        # Top key phrases in index
        title = '%s - %s' % ('Top key phrases', link)
        table = DisplayHTMLBlockTable(title, ['Key phrase', 'Search'])
        table.setColsCSSClass(['', 'iwla_search'])
        for phrase in top_key_phrases[:10]:
            table.appendRow([phrase[0], phrase[1]])
        index.appendBlock(table)
