import time

from iwla import IWLA
from iplugin import IPlugin
from display import *

class IWLADisplayTopDownloads(IPlugin):
    def __init__(self, iwla):
        super(IWLADisplayTopDownloads, self).__init__(iwla)
        self.API_VERSION = 1
        self.requires = ['IWLAPostAnalysisTopDownloads']

    def hook(self):
        top_downloads = self.iwla.getMonthStats()['top_downloads']
        top_downloads = sorted(top_downloads.items(), key=lambda t: t[1], reverse=True)

        # All in a file
        filename = 'top_downloads.html'
        path = self.iwla.getCurDisplayPath(filename)
        title = time.strftime('All Downloads - %B %Y', self.iwla.getCurTime())

        page = DisplayHTMLPage(title, path)
        table = DisplayHTMLBlockTable('All Downloads', ['URI', 'Hit'])
        table.setColsCSSClass(['', 'iwla_hit'])
        for (uri, entrance) in top_downloads:
            table.appendRow([uri, entrance])
        page.appendBlock(table)
                        
        self.iwla.getDisplay().addPage(page)

        link = '<a href=\'%s\'>All Downloads</a>' % (filename)
        title = '%s - %s' % ('Top Downloads', link)

        # Top in index
        index = self.iwla.getDisplayIndex()
        
        table = DisplayHTMLBlockTable(title, ['URI', 'Hits'])
        table.setColsCSSClass(['', 'iwla_hit'])
        for (uri, entrance) in top_downloads[:10]:
            table.appendRow([uri, entrance])
        index.appendBlock(table)
