import time

from iwla import IWLA
from iplugin import IPlugin
from display import *

class IWLADisplayTopVisitors(IPlugin):
    def __init__(self, iwla):
        super(IWLADisplayTopVisitors, self).__init__(iwla)
        self.API_VERSION = 1

    def hook(self):
        hits = self.iwla.getValidVisitors()
        count_hit_only = self.iwla.getConfValue('count_hit_only_visitors', False)
        display_visitor_ip = self.iwla.getConfValue('display_visitor_ip', False)

        top_bandwidth = [(k,v['bandwidth']) for (k,v) in hits.items() \
                             if count_hit_only or v['viewed_pages']]
        top_bandwidth = sorted(top_bandwidth, key=lambda t: t[1], reverse=True)
        top_visitors = [hits[h[0]] for h in top_bandwidth[:10]]

        index = self.iwla.getDisplayIndex()
        table = DisplayHTMLBlockTable('Top visitors', ['Host', 'Pages', 'Hits', 'Bandwidth', 'Last seen'])
        table.setColsCSSClass(['', 'iwla_page', 'iwla_hit', 'iwla_bandwith', ''])
        for super_hit in top_visitors:
            address = super_hit['remote_addr']
            if display_visitor_ip and\
                    super_hit.get('dns_name_replaced', False):
                address = '%s [%s]' % (address, super_hit['remote_ip'])

            row = [
                address,
                super_hit['viewed_pages'],
                super_hit['viewed_hits'],
                bytesToStr(super_hit['bandwidth']),
                time.asctime(super_hit['last_access'])
                ]
            table.appendRow(row)
        index.appendBlock(table)
